Index: src/compiler/interpreter-assembler.h |
diff --git a/src/compiler/interpreter-assembler.h b/src/compiler/interpreter-assembler.h |
index 65955a92ba205a915dfe934409697951a16cbc12..562bbeedceb9203e192d2e4eaf5b706726b1431f 100644 |
--- a/src/compiler/interpreter-assembler.h |
+++ b/src/compiler/interpreter-assembler.h |
@@ -105,11 +105,11 @@ class InterpreterAssembler { |
// Call constructor |constructor| with |arg_count| arguments (not |
// including receiver) and the first argument located at |
// |first_arg|. The |original_constructor| is the same as the |
// |constructor| for the new keyword, but differs for the super |
// keyword. |
- Node* CallConstruct(Node* original_constructor, Node* constructor, |
- Node* first_arg, Node* arg_count); |
+ Node* CallConstruct(Node* new_target, Node* constructor, Node* first_arg, |
+ Node* arg_count); |
// Call JSFunction or Callable |function| with |arg_count| |
// arguments (not including receiver) and the first argument |
@@ -105,11 +105,11 @@ class InterpreterAssembler { |
// Call constructor |constructor| with |arg_count| arguments (not |
// including receiver) and the first argument located at |
- // |first_arg|. The |original_constructor| is the same as the |
+ // |first_arg|. The |new_target| is the same as the |
// |constructor| for the new keyword, but differs for the super |
// keyword. |